import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.ths.concept.app.ths_concept_index_app as ths_concept_index_app
from datetime import datetime
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.utils.data_frame_util as data_frame_util
import pandas as pd
import mns_common.component.common_service_fun_api as common_service_fun_api


# 通过api 获取ths行业和指数
def get_ths_index_by_api(query_type):
    now_date = datetime.now()
    hour = now_date.hour
    minute = now_date.minute
    now_str_day = now_date.strftime('%Y-%m-%d')

    is_trade_day = trade_date_common_service_api.is_trade_day(now_str_day)

    if bool(1 - is_trade_day):
        last_trade_day = trade_date_common_service_api.get_before_trade_date(now_str_day, 1)
        begin_time = date_handle_util.no_slash_date(last_trade_day) + '093000'
        end_time = date_handle_util.no_slash_date(last_trade_day) + '150000'
    else:
        if hour < 9 or (hour == 9 and minute <= 25):
            last_trade_day = trade_date_common_service_api.get_before_trade_date(now_str_day, 2)
            begin_time = date_handle_util.no_slash_date(last_trade_day) + '093000'
            end_time = date_handle_util.no_slash_date(last_trade_day) + '150000'
        else:
            begin_time = date_handle_util.no_slash_date(now_str_day) + '093000'
            if hour == 9:
                hour = '0' + str(hour)
                end_time = date_handle_util.no_slash_date(now_str_day) + str(hour) + str(minute) + '00'
            elif (hour == 11 and minute >= 30) or (hour == 12):
                end_time = date_handle_util.no_slash_date(now_str_day) + '113000'
            elif hour >= 15:
                end_time = date_handle_util.no_slash_date(now_str_day) + '150000'
            else:
                end_time = date_handle_util.no_slash_date(now_str_day) + str(hour) + str(minute) + '00'

    df = ths_concept_index_app.get_ths_concept_his_info(begin_time, end_time, 500, query_type)
    if data_frame_util.is_empty(df):
        return pd.DataFrame()
    df['turnover'] = round(df['turnover'] / common_service_fun_api.HUNDRED_MILLION, 1)
    df['net_inflow_of_main_force'] = round(df['net_inflow_of_main_force'] / common_service_fun_api.TEN_THOUSAND, 1)
    df.fillna('', inplace=True)
    return df


if __name__ == '__main__':
    df_industry = get_ths_index_by_api(1)
    print(df_industry)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger
import time
import mns_common.component.main_line.main_line_zt_reason_service as main_line_zt_reason_service


def update_null_zt_reason(str_day):
    query = {"str_day": str_day, "$or": [{"zt_reason": "0"},
                                         {"zt_reason": ""},
                                         {"zt_reason": float('nan')},

                                         {"zt_analysis": "0"},
                                         {"zt_analysis": ""},
                                         {"zt_analysis": float('nan')},

                                         ]}
    stock_zt_pool_df_null_zt_reason = mongodb_util.find_query_data('stock_zt_pool', query)
    no_reason_list = []
    if data_frame_util.is_not_empty(stock_zt_pool_df_null_zt_reason):
        no_reason_list = list(stock_zt_pool_df_null_zt_reason['symbol'])

    # 比较两个表
    query_zt_reason_analysis = {"str_day": str_day}
    stock_zt_pool_df_exist = mongodb_util.find_query_data('stock_zt_pool', query_zt_reason_analysis)
    stock_zt_reason_df = mongodb_util.find_query_data('zt_reason_analysis', query_zt_reason_analysis)
    if data_frame_util.is_not_empty(stock_zt_pool_df_exist):
        if data_frame_util.is_empty(stock_zt_reason_df):
            no_reason_list.extend(list(stock_zt_pool_df_exist['symbol']))
        else:
            not_in_zt_reason_zf = stock_zt_pool_df_exist.loc[~stock_zt_pool_df_exist['symbol']
            .isin(stock_zt_reason_df['symbol'])]
            if data_frame_util.is_not_empty(not_in_zt_reason_zf):
                no_reason_list.extend(list(not_in_zt_reason_zf['symbol']))

            null_zt_reason_df = stock_zt_reason_df.loc[(stock_zt_reason_df['zt_reason'] == '')
                                                       | (stock_zt_reason_df['zt_analysis'] == '')]
            if data_frame_util.is_empty(null_zt_reason_df):
                no_reason_list.extend(list(null_zt_reason_df['symbol']))

    for symbol in no_reason_list:
        try:

            need_update_zt_pool_df = stock_zt_pool_df_exist.loc[
                stock_zt_pool_df_exist['symbol'].isin([symbol])]
            main_line_zt_reason_service.update_symbol_list_zt_reason_analysis(need_update_zt_pool_df, True)
            time.sleep(2)

            query_zt = {'symbol': symbol, 'str_day': str_day}
            zt_reason_analysis_one_df = mongodb_util.find_query_data('zt_reason_analysis', query_zt)
            if data_frame_util.is_empty(zt_reason_analysis_one_df):
                continue
            zt_analysis = list(zt_reason_analysis_one_df['zt_analysis'])[0]
            zt_reason = list(zt_reason_analysis_one_df['zt_reason'])[0]
            new_values = {'$set': {
                'zt_analysis': zt_analysis,
                'zt_reason': zt_reason
            }}
            mongodb_util.update_many(query_zt, new_values, 'stock_zt_pool')
            mongodb_util.update_many(query_zt, new_values, 'main_line_detail')

            if symbol in no_reason_list:
                no_reason_list.remove(symbol)
        except BaseException as e:
            logger.error("出现异常:{},{}", symbol, e)
            continue


if __name__ == '__main__':
    update_null_zt_reason('2026-01-07')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.api.kpl.theme.kpl_theme_api as kpl_theme_api
from mns_common.db.MongodbUtil import MongodbUtil
from datetime import datetime
import pandas as pd
import mns_common.constant.db_name_constant as db_name_constant
from loguru import logger
import mns_common.component.cookie.cookie_info_service as cookie_info_service
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.msg.push_msg_api as push_msg_api

mongodb_util = MongodbUtil('27017')


# 获取最大id
def query_max_theme_id():
    kpl_theme_max_one_df = mongodb_util.descend_query({}, db_name_constant.KPL_THEME_LIST, 'theme_id', 1)
    if data_frame_util.is_empty(kpl_theme_max_one_df):
        return 1
    else:
        return list(kpl_theme_max_one_df['theme_id'])[0]


def sync_new_kpl_theme_info():
    exist_max_theme_id = query_max_theme_id() + 1
    max_sync_theme_id = exist_max_theme_id + 10

    while exist_max_theme_id <= max_sync_theme_id:
        try:
            kpl_token = cookie_info_service.get_kpl_cookie()

            json_data = kpl_theme_api.kpl_theme_index(exist_max_theme_id, kpl_token)
            tables = json_data.get('Table')
            if tables is not None and len(tables) > 0:
                theme_name = json_data.get('Name')

                title = '新增开盘啦题材:' + theme_name
                push_msg_api.push_msg_to_wechat(title, title)

                # 保存到主线列表
                sync_kpl_theme_list(json_data, exist_max_theme_id)
                # 保存到主线详细列表
                sync_kpl_theme_detail(json_data, exist_max_theme_id)
                exist_max_theme_id = exist_max_theme_id + 1
        except BaseException as e:
            logger.error("更新新题材信息异常:{},{}", str(exist_max_theme_id), e)


def update_all_kpl_theme_info():
    theme_id = 0
    while theme_id < 2000:
        try:
            kpl_token = cookie_info_service.get_kpl_cookie()
            json_data = kpl_theme_api.kpl_theme_index(theme_id, kpl_token)
            # 保存到主线列表
            sync_kpl_theme_list(json_data, theme_id)
            # 保存到主线详细列表
            sync_kpl_theme_detail(json_data, theme_id)
            theme_id = theme_id + 1
        except BaseException as e:
            logger.error("出现异常:{}", e)


def sync_kpl_theme_list(json_data, theme_id):
    tables = json_data.get('Table')
    if tables is None or len(tables) == 0:
        return None

    theme_name = json_data.get('Name')

    logger.info("同步题材:{},{}", str(theme_id), theme_name)
    brief_intro = json_data.get('BriefIntro')
    introduction = json_data.get('Introduction')
    kpl_create_time = covert_time(json_data.get('CreateTime'))
    kpl_update_time = covert_time(json_data.get('UpdateTime'))
    now_date = datetime.now()
    sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')

    theme_dict = {
        '_id': theme_id,
        'theme_id': theme_id,
        'theme_name': theme_name,
        'brief_intro': brief_intro,
        'introduction': introduction,
        'kpl_create_time': kpl_create_time,
        'kpl_update_time': kpl_update_time,
        'sync_time': sync_time,
    }

    ths_concept_one_df = pd.DataFrame(theme_dict, index=[1])
    mongodb_util.save_mongo(ths_concept_one_df, db_name_constant.KPL_THEME_LIST)


def sync_kpl_theme_detail(json_data, theme_id):
    tables = json_data.get('Table')
    theme_name = json_data.get('Name')
    if tables is None or len(tables) == 0:
        return None
    for table in tables:
        save_theme_l1(table, theme_name, theme_id)

    return tables


def save_theme_l1(table, theme_name, theme_id):
    theme_l1 = table.get('Level1')

    first_shelve_time = covert_time(theme_l1.get('FirstShelveTime'))
    theme_l1_id = theme_l1.get('ID')
    is_new = theme_l1.get('IsNew')
    theme_l1_name = theme_l1.get('Name')
    update_cache_time = covert_time(theme_l1.get('UpdateCacheTime'))
    zs_code = theme_l1.get('ZSCode')
    now_date = datetime.now()
    sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
    theme_dict = {
        '_id': str(theme_l1_id),
        'theme_l1_id': str(theme_l1_id),
        'theme_l1_name': str(theme_l1_name),
        'theme_id': str(theme_id),
        'theme_name': str(theme_name),
        'first_shelve_time': first_shelve_time,
        'update_cache_time': update_cache_time,
        'zs_code': zs_code,
        'is_new': is_new,
        'sync_time': sync_time,
    }

    ths_concept_one_df = pd.DataFrame(theme_dict, index=[1])
    mongodb_util.save_mongo(ths_concept_one_df, db_name_constant.KPL_THEME_LIST_L1)
    stock_list = theme_l1.get('Stocks')
    if len(stock_list) != 0:
        save_theme_stocks(stock_list, theme_name, theme_id, theme_l1_name, theme_l1_id, '无', 0)
    else:
        theme_l2_list = table.get('Level2')
        save_theme_l2(theme_l2_list, theme_name, theme_id, theme_l1_name, theme_l1_id)


def save_theme_l2(theme_l2_list, theme_name, theme_id, theme_l1_name, theme_l1_id):
    for theme_l2_one in theme_l2_list:

        first_shelve_time = covert_time(theme_l2_one.get('FirstShelveTime'))
        theme_l2_id = theme_l2_one.get('ID')
        is_new = theme_l2_one.get('IsNew')
        theme_l2_name = theme_l2_one.get('Name')
        update_cache_time = covert_time(theme_l2_one.get('UpdateCacheTime'))
        zs_code = theme_l2_one.get('ZSCode')
        now_date = datetime.now()
        sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
        theme_dict = {
            '_id': str(theme_l2_id),
            'theme_l2_id': str(theme_l2_id),
            'theme_l2_name': str(theme_l2_name),

            'theme_l1_id': str(theme_l1_id),
            'theme_l1_name': str(theme_l1_name),
            'theme_id': str(theme_id),
            'theme_name': str(theme_name),
            'first_shelve_time': first_shelve_time,
            'update_cache_time': update_cache_time,
            'zs_code': zs_code,
            'is_new': is_new,
            'sync_time': sync_time,
        }

        ths_concept_one_df = pd.DataFrame(theme_dict, index=[1])
        mongodb_util.save_mongo(ths_concept_one_df, db_name_constant.KPL_THEME_LIST_L2)
        stock_list = theme_l2_one.get('Stocks')
        if len(stock_list) != 0:
            save_theme_stocks(stock_list, theme_name, theme_id, theme_l1_name, theme_l1_id, theme_l2_name, theme_l2_id)


def save_theme_stocks(stock_list, theme_name, theme_id, theme_l1_name, theme_l1_id, theme_l2_name, theme_l2_id):
    stock_list_df = pd.DataFrame(stock_list)
    stock_list_df = stock_list_df.rename(columns={
        "StockID": "symbol",
        "IsZz": "is_zz",
        "IsHot": "is_hot",
        "Reason": "reason",
        "FirstShelveTime": "first_shelve_time",
        "UpdateCacheTime": "update_cache_time",
        "IsNew": "is_new",
        "prod_name": "prod_name",
        "Hot": "hot",
    })
    stock_list_df["first_shelve_time"] = stock_list_df["first_shelve_time"].apply(covert_time)
    stock_list_df["update_cache_time"] = stock_list_df["update_cache_time"].apply(covert_time)

    stock_list_df['theme_id'] = str(theme_id)
    stock_list_df['theme_name'] = theme_name

    stock_list_df['theme_l1_id'] = str(theme_l1_id)
    stock_list_df['theme_l1_name'] = theme_l1_name

    stock_list_df['theme_l2_name'] = theme_l2_name
    stock_list_df['theme_l2_id'] = str(theme_l2_id)

    stock_list_df['_id'] = (stock_list_df['symbol']
                            + '_'
                            + stock_list_df['theme_id']
                            + '_'
                            + stock_list_df['theme_l1_id']
                            + '_'
                            + stock_list_df['theme_l2_id'])
    now_date = datetime.now()
    sync_time = now_date.strftime('%Y-%m-%d %H:%M:%S')
    stock_list_df['sync_time'] = sync_time
    mongodb_util.save_mongo(stock_list_df, db_name_constant.KPL_THEME_DETAILS)


def covert_time(timestamp_str):
    timestamp = int(timestamp_str)
    if timestamp == 0:
        return "1989-06-04"
    else:
        # 3. 转换为本地时区的datetime对象
        dt_local = datetime.fromtimestamp(timestamp)
        # 4. 格式化为「年月日 时分秒」的字符串（格式可自定义）
        datetime_str = dt_local.strftime('%Y-%m-%d %H:%M:%S')
        return datetime_str


if __name__ == '__main__':
    update_all_kpl_theme_info()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.date_handle_util as date_handle_util
import mns_scheduler.k_line.hot_stocks.recent_hot_stocks_clean_service as recent_hot_stocks_clean_service
import mns_scheduler.k_line.clean.daily.daily_k_line_clean_common_service as daily_k_line_clean_common_service
from mns_common.component.classify.symbol_classify_param import stock_type_classify_param
import mns_scheduler.k_line.clean.week_month.sub_new_week_month_k_line_service as sub_new_week_month_k_line_service

mongodb_util = MongodbUtil('27017')
# 普通股日线查询数据 60
NORMAL_DAILY_K_LINE_NUMBER = 60


def handle_day_line(k_line_info, str_day, symbol, deal_days):
    sub_stock_new_max_deal_days = stock_type_classify_param['sub_new_stock_max_deal_days']
    if deal_days > sub_stock_new_max_deal_days:
        return handle_day_line_normal(k_line_info, str_day, symbol, deal_days)

    else:
        # 交易日小于100天的
        return handle_day_line_sub_new(k_line_info, str_day, symbol, deal_days)

    # 处理日线


def handle_day_line_sub_new(k_line_info, str_day, symbol, deal_days):
    k_line_info['deal_days'] = deal_days
    query = {"symbol": symbol, 'date': {"$lt": date_handle_util.no_slash_date(str_day)}}
    stock_qfq_daily = mongodb_util.descend_query(query, 'stock_qfq_daily', 'date', deal_days)
    # 初始化数据
    k_line_info = daily_k_line_clean_common_service.init_day_line_data(k_line_info, stock_qfq_daily)
    if stock_qfq_daily.shape[0] == 0:
        return k_line_info

    # 当前交易日k线信息
    stock_qfq_daily_one = stock_qfq_daily.iloc[0:1]
    # 设置当天k线形态 下一个交易日判断当前交易日k线形态
    stock_qfq_daily_one = daily_k_line_clean_common_service.set_k_line_patterns(stock_qfq_daily_one.copy())
    # 设置历史k线列表
    stock_qfq_daily_one = daily_k_line_clean_common_service.set_history_list(stock_qfq_daily_one.copy(),
                                                                             stock_qfq_daily.copy())
    # 修改字段名称
    k_line_info = daily_k_line_clean_common_service.k_line_field_fix_name(k_line_info.copy(),
                                                                          stock_qfq_daily_one.copy())
    if stock_qfq_daily.shape[0] == 1:
        # 上市第二天的股票
        return k_line_info
    # 排除上市第一天的股票
    stock_qfq_daily = stock_qfq_daily.iloc[0:deal_days - 1]
    # 计算换手平均值 k线 5 10 20 30 60均线
    stock_qfq_daily = daily_k_line_clean_common_service.calculate_exchange_and_k_line_avg_param(stock_qfq_daily)
    # 计算30天最大涨幅
    k_line_info = daily_k_line_clean_common_service.calculate_30_day_max_chg(stock_qfq_daily, k_line_info)
    # 设置五日k线和
    k_line_info = daily_k_line_clean_common_service.set_sum_five_chg(k_line_info, deal_days)
    # 计算当前交易日开盘时的涨幅
    k_line_info = daily_k_line_clean_common_service.calculate_open_chg(stock_qfq_daily, k_line_info)
    # 计算 昨日最高点到开盘涨幅差值 and   # 昨日最高点到当日收盘涨幅之间的差值 and  # 昨日收盘到当日开盘涨幅之间的差值
    k_line_info = daily_k_line_clean_common_service.calculate_chg_diff_value(k_line_info)
    # 计算 月线
    k_line_info = sub_new_week_month_k_line_service.handle_month_line(k_line_info, stock_qfq_daily, deal_days)
    # 计算周线
    k_line_info = sub_new_week_month_k_line_service.handle_week_line(k_line_info, stock_qfq_daily, deal_days)

    # 排除最近有三板以上的股票 todo
    # 计算最近热门大涨的股票
    recent_hot_stocks_clean_service.calculate_recent_hot_stocks(stock_qfq_daily, symbol, str_day)
    # 修改 avg name
    k_line_info = daily_k_line_clean_common_service.fix_avg_slope_name(k_line_info, stock_qfq_daily)

    return k_line_info


def handle_day_line_normal(k_line_info, str_day, symbol, deal_days):
    # 取五天刚好包含一周 todo 选择60天的历史记录

    query = {"symbol": symbol, 'date': {"$lt": date_handle_util.no_slash_date(str_day)}}
    stock_qfq_daily = mongodb_util.descend_query(query, 'stock_qfq_daily', 'date', NORMAL_DAILY_K_LINE_NUMBER)
    if stock_qfq_daily.shape[0] == 0:
        return k_line_info
    # 初始化数据
    k_line_info = daily_k_line_clean_common_service.init_day_line_data(k_line_info, stock_qfq_daily)
    # 计算30天最大涨幅
    k_line_info = daily_k_line_clean_common_service.calculate_30_day_max_chg(stock_qfq_daily, k_line_info)
    # 计算换手平均值 k线 5 10 20 30 60均线
    stock_qfq_daily = daily_k_line_clean_common_service.calculate_exchange_and_k_line_avg_param(stock_qfq_daily)
    # 当前交易日k线信息
    stock_qfq_daily_one = stock_qfq_daily.iloc[0:1]
    # 设置当天k线形态 下一个交易日判断当前交易日k线形态
    stock_qfq_daily_one = daily_k_line_clean_common_service.set_k_line_patterns(stock_qfq_daily_one.copy())
    # 设置历史k线列表
    stock_qfq_daily_one = daily_k_line_clean_common_service.set_history_list(stock_qfq_daily_one.copy(),
                                                                             stock_qfq_daily.copy())
    # 修改字段名称
    k_line_info = daily_k_line_clean_common_service.k_line_field_fix_name(k_line_info.copy(),
                                                                          stock_qfq_daily_one.copy())
    # 设置五日k线和
    k_line_info = daily_k_line_clean_common_service.set_sum_five_chg(k_line_info, deal_days)
    # 计算当前交易日开盘时的涨幅
    k_line_info = daily_k_line_clean_common_service.calculate_open_chg(stock_qfq_daily, k_line_info)
    # 计算 昨日最高点到开盘涨幅差值 and   # 昨日最高点到当日收盘涨幅之间的差值 and  # 昨日收盘到当日开盘涨幅之间的差值
    k_line_info = daily_k_line_clean_common_service.calculate_chg_diff_value(k_line_info)

    # 排除最近有三板以上的股票 todo
    # 计算最近热门大涨的股票
    recent_hot_stocks_clean_service.calculate_recent_hot_stocks(stock_qfq_daily, symbol, str_day)
    # 修改 avg name
    k_line_info = daily_k_line_clean_common_service.fix_avg_slope_name(k_line_info, stock_qfq_daily)
    return k_line_info


# if __name__ == '__main__':
#     query1 = {"symbol": '301596', 'date': {"$lte": date_handle_util.no_slash_date('2024-05-31')}}
#     stock_qfq_daily_301596 = mongodb_util.descend_query(query1, 'stock_qfq_daily', 'date', 15)
#     stock_qfq_daily_301596.shape[0]
#     stock_qfq_daily1 = stock_qfq_daily_301596.iloc[0:14]



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.company_info.task.company_industry_info_task as company_industry_info_task
import mns_scheduler.company_info.task.company_business_info_task as company_business_info_task
import mns_scheduler.company_info.task.company_base_info_task as company_base_info_task
import mns_scheduler.company_info.task.company_hold_info_task as company_hold_info_task
import mns_scheduler.company_info.task.company_announce_info_task as company_announce_info_task
from mns_scheduler.company_info.common.company_common_query_service import get_company_info
from datetime import datetime
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger


def sync_all_company_task():
    # 同步公司行业信息
    company_industry_info_task.sync_company_industry_info_task([])
    logger.info("[全量]同步公司[行业]信息完成")
    # 同步公司业务信息
    company_business_info_task.sync_company_business_task([])
    logger.info("[全量]同步公司[业务]信息完成")
    # 同步公司基本信息
    company_base_info_task.sync_company_base_info_task([])
    logger.info("[全量]同步公司[基本]信息完成")
    # 同步公司控股信息
    company_hold_info_task.sync_all_company_hold_info_task([])
    logger.info("[全量]同步公司[控股]信息完成")
    # 同步公司公告信息
    company_announce_info_task.sync_company_announce_task([])
    logger.info("[全量]同步公司[公告]信息完成")


def sync_new_stock_company_task():
    all_company_info_df = get_company_info()

    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    # 去掉横线并转换为整数
    now_day = int(str_day.replace('-', ''))

    new_company_info_df = all_company_info_df.loc[
        (all_company_info_df['list_date'] == 19890604) | (all_company_info_df['list_date'] >= now_day)]
    if data_frame_util.is_empty(new_company_info_df):
        return
    symbol_list = list(new_company_info_df['symbol'])
    # 同步公司行业信息
    company_industry_info_task.sync_company_industry_info_task(symbol_list)
    logger.info("[新股]同步公司[行业]信息完成")
    # 同步公司业务信息
    company_business_info_task.sync_company_business_task(symbol_list)
    logger.info("[新股]同步公司[业务]信息完成")
    # 同步公司基本信息
    company_base_info_task.sync_company_base_info_task(symbol_list)
    logger.info("[新股]同步公司[基本]信息完成")
    # 同步公司控股信息
    company_hold_info_task.sync_all_company_hold_info_task(symbol_list)
    logger.info("[新股]同步公司[控股]信息完成")
    # 同步公司公告信息
    company_announce_info_task.sync_company_announce_task(symbol_list)
    logger.info("[新股]同步公司[公告]信息完成")


if __name__ == '__main__':
    sync_new_stock_company_task()
    sync_all_company_task()



import warnings

# 忽略所有警告
warnings.filterwarnings("ignore")
from loguru import logger
import mns_scheduler.dt.stock_dt_pool_sync as stock_dt_pool_sync_api
import mns_scheduler.zb.stock_zb_pool_sync as stock_zb_pool_sync_api
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
import mns_scheduler.k_line.month_week_daily.daily_week_month_line_sync as daily_week_month_line_sync_api
import mns_scheduler.db.col_move_service as col_move_service
import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
import mns_scheduler.zt.export.export_kcx_high_chg_open_data_to_excel as export_kcx_high_chg_open_data_to_excel
import mns_scheduler.zt.connected_boards.zt_five_boards_sync_api as zt_five_boards_sync_api
import mns_scheduler.zt.zt_pool.em_zt_pool_sync_api as em_zt_pool_sync_api
import mns_scheduler.k_line.clean.k_line_info_clean_task as k_line_info_clean_service
import mns_scheduler.open.sync_one_day_open_data_to_db_service as sync_one_day_open_data_to_db_service
import mns_scheduler.zt.high_chg.sync_high_chg_pool_service as sync_high_chg_pool_service
import mns_scheduler.zt.high_chg.sync_high_chg_real_time_quotes_service as sync_high_chg_real_time_quotes_service
import mns_scheduler.zt.zt_pool.ths_zt_pool_sync_api as ths_zt_pool_sync_api
import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
from datetime import datetime

# 定时同步每日交易行情数据(前复权)
def stock_daily_sync_qfq():
    logger.info('同步每日行情数据(前复权):' + str_day)
    daily_week_month_line_sync_api.sync_all_daily_data('daily',
                                                       'qfq', 'stock_qfq_daily', str_day)


# 同步当日k c x 高涨幅数据
def realtime_quotes_now_zt_kc_data_sync():
    if trade_date_common_service_api.is_trade_day(str_day):
        # 同步当日kcx 高涨幅 当天交易数据和开盘数据
        kcx_high_chg_open_data_sync.sync_all_kc_zt_data(str_day, None)
        # 同步当日开盘数据
        sync_one_day_open_data_to_db_service.sync_one_day_open_data(str_day)
        # 涨停数据同步到excel
        export_kcx_high_chg_open_data_to_excel.export_kc_zt_data(str_day)


# 同步涨停池
def sync_stock_zt_pool():
    if trade_date_common_service_api.is_trade_day(str_day):
        logger.info('同步当天涨停池股开始')
        em_stock_zt_pool = em_zt_pool_sync_api.save_zt_info(str_day)
        zt_five_boards_sync_api.update_five_connected_boards_task(em_stock_zt_pool)
        logger.info('同步ths股票涨停池')
        ths_zt_pool_df = ths_zt_pool_sync_api.ths_zt_pool(str_day, None)
        ths_zt_pool_sync_api.save_ths_zt_pool(ths_zt_pool_df, str_day)
        logger.info('同步当天涨停池股票完成')


# 保存今天高涨幅数据
def sync_toady_stock_zt_pool():
    logger.info('同步今天涨幅大于9.5的symbol')
    # 同步高涨幅实时行情
    sync_high_chg_real_time_quotes_service.sync_high_chg_real_time_quotes(str_day)
    # 同步高涨幅列表
    sync_high_chg_pool_service.sync_stock_high_chg_pool_list(str_day, None)


# 计算下一个交易日k线数据
def generate_new_day_k_line_info():
    # 生成下一个交易日日期k线数据 number=2 获取下一个交易日 日期
    if trade_date_common_service_api.is_trade_day(str_day):
        dis_number = 2
    else:
        dis_number = 1
    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, dis_number)
    k_line_info_clean_service.sync_k_line_info_task(next_trade_day)
    logger.info('计算当日k线信息完成:{}', str_day)


# 同步一天k线 涨停 数据
def sync_daily_data_info():
    # 同步k线数据
    try:
        stock_daily_sync_qfq()
    except BaseException as e:
        logger.error("同步当日k线数据异常:{}", e)

    # 同步当日k c x 高涨幅数据
    try:
        realtime_quotes_now_zt_kc_data_sync()
    except BaseException as e:
        logger.error("同步当日kcx高涨幅数据异常:{}", e)

    # 同步涨停池数据信息
    try:
        sync_stock_zt_pool()
    except BaseException as e:
        logger.error("同步涨停数据信息异常:{}", e)

    # 同步今日高涨幅数据 依赖涨停股票池的数据
    try:
        sync_toady_stock_zt_pool()
    except BaseException as e:
        logger.error("同步今日高涨幅数据异常:{}", e)

    # 计算当日k线数据
    try:
        generate_new_day_k_line_info()
    except BaseException as e:
        logger.error("计算当日k线数据异常:{}", e)


# 跌停信息
def sync_stock_dt_pool():
    if trade_date_common_service_api.is_trade_day(str_day):
        stock_dt_pool_sync_api.sync_stock_dt_pool(str_day)
        logger.info("同步跌停信息任务执行成功:{}", str_day)


# 炸板信息
def sync_stock_zb_pool():
    if trade_date_common_service_api.is_trade_day(str_day):
        stock_zb_pool_sync_api.sync_stock_zb_pool(str_day)
        logger.info("同步炸板信息任务执行成功:{}", str_day)
    # 同步停复牌信息
    sync_stock_tfp()


# 同步停复牌信息
def sync_stock_tfp():
    stock_tfp_info_sync.sync_stock_tfp(str_day)


#  当天实时数据备份
def col_data_move():
    logger.info('当天实时数据备份:{}', str_day)
    if trade_date_common_service_api.is_trade_day(str_day):
        col_move_service.sync_col_move(str_day)


if __name__ == '__main__':
    # todo 修改日期
    str_day = '2026-01-05'
    # col_data_move()
    generate_new_day_k_line_info()
    # sync_stock_zt_pool()
    # sync_stock_dt_pool()
    # sync_stock_zb_pool()
